--[[
   Copyright 2011 Kelly Riley (lunarwater)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
]]
import "Compendium.Items.CompendiumItemsDB";
import "Compendium.Common.Utils";
import "Compendium.Common.UI";
import "Compendium.Items.ItemCategoryMenu";
import "Compendium.Common.Resources";

local rsrc = {};
local qualityMap = {
	u = "Uncommon",
	c = "Common",
	e = "Epic",
	r = "Rare",
	i = "Incomparable",
	un = "Unknown"
};

CompendiumItemWindow = class( Compendium.Common.UI.CompendiumWindow );
function CompendiumItemWindow:Constructor(record)
    Compendium.Common.UI.CompendiumWindow.Constructor( self );
	rsrc = Compendium.Common.Resources.Bundle:GetResources();
	
    self:SetSize(400,200);
    self:SetOpacity( 1 );
    self:SetVisible(false);
    self:SetText( 'Add Item' );
	
	local labelLeft, inputLeft = 0, 150;
	local top = 30;
	
	local lbl = Turbine.UI.Label();
	lbl:SetParent( self );
	lbl:SetText('Drag & Drop item:');
	lbl:SetPosition(labelLeft, top);
    lbl:SetSize( inputLeft - labelLeft - 5, 36 );
    lbl:SetFont(self.fontFace);
    lbl:SetForeColor(self.fontColor);    
    lbl:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter  );
    
	local qs = Turbine.UI.Lotro.Quickslot();
	if record ~= nil then
	    local sc = Turbine.UI.Lotro.Shortcut( 2, '0x0000000000000000,0x' .. record.id);--'0x0000000000000000,0x700005B4' );
	    qs:SetShortcut( sc );
    end
    qs:SetParent(self);
    qs:SetAllowDrop(true);
    qs:SetPosition(inputLeft, top);
    qs:SetSize(36,36);
    qs:SetVisible(true);
    
    top = top + 40;
    lbl = Turbine.UI.Label();
	lbl:SetParent( self );
	lbl:SetText('Or Enter Item Id:');
	lbl:SetPosition(labelLeft, top);
    lbl:SetSize( inputLeft - labelLeft - 5, 18 );
    lbl:SetFont(self.fontFace);
    lbl:SetForeColor(self.fontColor);    
    lbl:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter  );
    
    local idInput =Turbine.UI.Lotro.TextBox();
    idInput:SetParent(self);
    idInput:SetPosition(inputLeft,top);
    idInput:SetSize(120,18);
    idInput:SetBackColor(Turbine.UI.Color(.25,.35,.55));
    idInput:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
    idInput:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
    idInput:SetForeColor(self.fontColor);
	if record ~= nil then
		pcall(function() idInput:SetText(tonumber(record.id)) end);
    end
    idInput:SetOutlineColor(Turbine.UI.Color(0,0,0));
    idInput:SetFontStyle(Turbine.UI.FontStyle.Outline);
    idInput:SetWantsUpdates(false);
    idInput.Text="";
    idInput.FocusGained=function()
            idInput:SetWantsUpdates(true);
    end
    idInput.FocusLost=function()
            idInput:SetWantsUpdates(false);
    end
    idInput.Update=function()
    	local text = idInput:GetText();
        if idInput.Text ~= text and string.len(text) == 10 then
			pcall(function()
			    local sc = Turbine.UI.Lotro.Shortcut( 2, '0x0000000000000000,0x' .. string.format('%x',text));
		    	qs:SetShortcut( sc );
		    end);
        end
    end   
    
    qs.DragDrop = function( sender, args )
        local shortcut = args.DragDropInfo:GetShortcut();
		local i, j, val2 = string.find(shortcut:GetData(), ",(0x[ABCDEFGH0123456789]+)");
		if val2 ~= nil then
        	pcall(function() idInput:SetText(tonumber(val2)) end);
        end
    end;
	    		    
end




